#!/usr/bin/perl
##
# A N O N C P . P L
#
# a script that takes the unix cp file specification options
#
# perl anontree.pl directory ...
#
# which processes all the *.m4a files in the directory and
# strips out all the user identification gunk that Apple
# adds on iTunes "DRM free" songs.
#
# NB: make sure you install the latest version of the
# most excellent Audio::M4P::QuickTime perl module.
# You can do this with this command in a Terminal:
#     sudo cpan install Audio::M4P::QuickTime
# and just say yes to all the prompts it produces.
#
# JKF 21 May 2010 Re-written to convert a whole directory tree in place.
# JKF Contact Jules@Jules.FM for more info.
#
##

use strict;
use warnings;

use File::Find;
use Audio::M4P::QuickTime;

my $usage = q{
usage:
  perl anontree.pl directory ...
};

@ARGV or die "You must give me at least one directory name!\n";

find(\&ProcessFile, @ARGV);
exit 0;

sub ProcessFile {
  my $source = $_;

  return unless -f $source && $source =~ /\.m4a$/i;

  my $dest = ".$source";

  my $qt = Audio::M4P::QuickTime->new( file => $source );
  $qt->FindAtom("mp4a") || warn $File::Find::name . ": not a mpeg 4 file\n";
  $qt->CleanAppleM4aPersonalData();
  $qt->WriteFile($dest);

  unlink $source and rename $dest, $source;

  print "Stripped $File::Find::name\n";
}

0;
